@@ -40,13 +40,14 @@
     * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "drkonqi.h"
+#include "drkonqi_debug.h"
 
-#include <QtCore/QPointer>
-#include <QtCore/QTextStream>
-#include <QtCore/QTimerEvent>
-#include <QtCore/QTemporaryFile>
-#include <QtCore/QDebug>
-#include <QtWidgets/QFileDialog>
+#include <QPointer>
+#include <QTextStream>
+#include <QTimerEvent>
+#include <QTemporaryFile>
+#include <QDebug>
+#include <QFileDialog>
 
 #include <KMessageBox>
 #include <KCrash>
@@ -96,7 +97,7 @@ public:
     }
 protected:
     void timerEvent(QTimerEvent *event) override {
-        qDebug() << "Enabling drkonqi crash catching";
+        qCDebug(DRKONQI_LOG) << "Enabling drkonqi crash catching";
         KCrash::setDrKonqiEnabled(true);
         killTimer(event->timerId());
         this->deleteLater();
@@ -113,7 +114,7 @@ bool DrKonqi::init()
         // is not drkonqi already. If it is drkonqi, delay enabling crash catching
         // to prevent recursive crashes (in case it crashes at startup)
         if (crashedApplication()->fakeExecutableBaseName() != QLatin1String("drkonqi")) {
-            qDebug() << "Enabling drkonqi crash catching";
+            qCDebug(DRKONQI_LOG) << "Enabling drkonqi crash catching";
             KCrash::setDrKonqiEnabled(true);
         } else {
             new EnableCrashCatchingDelayed;
